/*
  Synthino Library
  Copyright (C) 2014 nootropic design, LLC
  All rights reserved.
*/


#include "Synthino.h"

SynthinoClass::SynthinoClass() {
}



void SynthinoClass::begin() {
  pinMode(SCK, OUTPUT);
  pinMode(MISO, INPUT);
  pinMode(MOSI, OUTPUT);
  pinMode(SS, OUTPUT);

  digitalWrite(SCK, LOW);
  digitalWrite(MISO, LOW);
  digitalWrite(MOSI, LOW);
  digitalWrite(SS, HIGH);

  // Configure SPI
  SPCR |= _BV(SPE);    // enable SPI
  SPCR &= ~_BV(SPIE);  // SPI interrupts off
  SPCR &= ~_BV(DORD);  // MSB first
  SPCR |= _BV(MSTR);   // SPI master mode
  SPCR &= ~_BV(CPOL);  // leading edge rising
  SPCR &= ~_BV(CPHA);  // sample on leading edge
  SPCR &= ~_BV(SPR1);  // speed = clock/4
  SPCR &= ~_BV(SPR0);  
  SPSR |= _BV(SPI2X);  // 2X speed

  // Disable Timer1 interrupt
  TIMSK1 &= ~_BV(TOIE1);

  TCCR1A = 0;
  TCCR1B = 0;

  // Set prescalar to 1;
  TCCR1B |= _BV(CS10);

  // Enable Timer1 interrupt
  TIMSK1 |= _BV(TOIE1);
}

void SynthinoClass::output(unsigned int signal) {
  SELECT_DAC;
  spiWrite(DAC_CONFIG | ((signal >> 8) & 0xF)); // 4 config bits and bits 11-8
  spiWrite(signal); // bits 7-0
  DESELECT_DAC;
}

void SynthinoClass::output_8bit(byte signal) {
  SELECT_DAC;
  spiWrite(DAC_CONFIG | ((signal >> 4) & 0xF)); // 4 config bits and bits 7-4
  spiWrite(signal << 4); // bits 3-0 of 8 bit signal.  Least significant 4 bits are 0
  DESELECT_DAC;
}

SynthinoClass Synthino = SynthinoClass();
