/*
  Synthino Library
  Copyright (C) 2014 nootropic design, LLC
  All rights reserved.
*/

#ifndef Synthino_h
#define Synthino_h

#include <inttypes.h>
#if defined(ARDUINO) && ARDUINO >= 100
  #include "Arduino.h"
#else
  #include "WProgram.h"
  #include <pins_arduino.h>
#endif


#define UINT16_MAX 65535

#if defined(__AVR_ATmega328P__) || defined(__AVR_ATmega168__) 
// PB5 = D13
#define SCK_LOW PORTB &= ~0x20
#define SCK_HIGH PORTB |= 0x20
// PB4 = D12
#define MISO_READ PINB & 0x10
// PB2 = D10
#define SELECT_DAC PORTB &= ~0x04
#define DESELECT_DAC PORTB |= 0x04
#endif

#define DAC_CONFIG 0x30 // DACa, unbuffered, gain=1, not shutdown

#define NOP asm volatile ("nop\n\t")

class SynthinoClass {
public:
  SynthinoClass();
  void begin();
  void output(unsigned int signal);
  void output_8bit(byte signal);
};

static inline __attribute__((always_inline)) byte spiRead() {
  SPDR = 0xFF; // start SPI clock
  while (!(SPSR & _BV(SPIF)));
  return SPDR;
}

static inline __attribute__((always_inline)) byte spiWrite(byte data) {
  SPDR = data;
  while (!(SPSR & _BV(SPIF)));
  return SPDR;
}

extern SynthinoClass Synthino;

#endif /* Synthino_h */

